#import "ViewController.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    _data = [[NSMutableArray alloc]init];
    
    [self prepareData:10];
    
    //create a data source helper from the data model.
    _dsh = [[IGCategoryDateSeriesDataSourceHelper alloc]initWithData:_data valuePath:@"value" andDatePath:@"date"];

    //this is needed if we ever set axis display type to discrete
    _dsh.labelPath = @"label";
    
    _chart = [[IGChartView alloc]initWithFrame:CGRectInset(self.view.frame, 20, 20)];
    
    //this is needed to get calls to -labelForAxis, where we do our formatting.
    _chart.delegate = self;
    
    IGCategoryDateTimeXAxis *xAxis = [[IGCategoryDateTimeXAxis alloc]initWithKey:@"xAxis"];
    xAxis.extent = 80;
    xAxis.labelOrientationAngle = 90;
    xAxis.displayType = IGTimeAxisDisplayTypeContinuous;
    
    IGNumericYAxis *yAxis = [[IGNumericYAxis alloc]initWithKey:@"yAxis"];
    yAxis.minimum = 0;
    yAxis.maximum = 10;
    
    IGLineSeries *series = [[IGLineSeries alloc]initWithKey:@"series"];
    series.xAxis = xAxis;
    series.yAxis = yAxis;
    series.dataSource = _dsh;
    series.thickness = 5;
    
    [_chart addAxis:xAxis];
    [_chart addAxis:yAxis];
    [_chart addSeries:series];
    
    [self.view addSubview:_chart];
}

//populate the data array with some data.
-(void)prepareData:(int)numberOfPoints
{
    NSDateFormatter *formatter = [[NSDateFormatter alloc]init];
    [formatter setDateFormat:@"MMM dd"];
    
    for (int i=0; i<numberOfPoints; i++)
    {
        CGFloat value = arc4random()%10;
        NSTimeInterval month = 3600 * 24 * 30;
        NSDate *date = [NSDate dateWithTimeIntervalSinceNow:month * sqrt(i)];
        NSString *label = [formatter stringFromDate:date];
        DataModel *item = [[DataModel alloc]initWithValue:value date:date label:label];
        [_data addObject:item];
    }
}

//handle formatting for the axis labels.
-(NSString *)chartView:(IGChartView *)chartView labelForAxis:(IGAxis *)axis withItem:(NSObject *)item
{
    if ([item isKindOfClass:[NSNumber class]])
    {
        NSNumber *yAxisLabel = (NSNumber*)item;
        return [yAxisLabel stringValue];
    }
    
    if ([item isKindOfClass:[NSDate class]])
    {
        NSDate *xAxisLabel = (NSDate*)item;
        NSDateFormatter *formatter = [[NSDateFormatter alloc]init];
        [formatter setDateFormat:@"MMM dd"];
        return [formatter stringFromDate:xAxisLabel];
    }
    
    if ([item isKindOfClass:[IGCategoryDatePoint class]])
    {
        IGCategoryDatePoint *point = (IGCategoryDatePoint*)item;
        return point.label;
    }
    
    return nil;
}

@end


@implementation DataModel
-(id)initWithValue:(CGFloat)value date:(NSDate *)date label:(NSString *)label
{
    self = [super init];
    if (self)
    {
        self.value = value;
        self.label = label;
        self.date = date;
    }
    return self;
}
@end